@@ -1,5 +1,4 @@
 import json
-import requests
 import pytz
 from datetime import datetime, timezone
 from adsb_tools.utils import requests_utils
@@ -43,7 +42,7 @@ def get_grid_data(latitude, longitude):
     Gets weather grid data which includes forecast url and local timezone
     """
     grid_url = f'https://api.weather.gov/points/{latitude},{longitude}'
-    grid_response = requests.get(grid_url)
+    grid_response = requests_utils.call_url(grid_url)
     grid_json_obj = json.loads(grid_response.content)
 
     grid_properties =  grid_json_obj['properties']
@@ -59,7 +58,7 @@ def get_weather_data(forcast_hourly_url, local_timezone_name):
     """
     local_timezone_obj = pytz.timezone(local_timezone_name)
 
-    weather_response = requests.get(forcast_hourly_url)
+    weather_response = requests_utils.call_url(forcast_hourly_url)
     weather_json_obj = json.loads(weather_response.content)
 
     current_weather = get_current_event(weather_json_obj['properties']['periods'])
